<?php

namespace App\Http\Controllers\Dashboard;

use App\DataTables\ProjectsDataTable;
use App\Exports\ProjectsExport;
use App\Http\Controllers\Controller;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Http\Request;
use App\Models\Project;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rule;
use Maatwebsite\Excel\Facades\Excel;

class ProjectsController extends Controller
{
    //
    //
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(ProjectsDataTable $dataTable){
        return $dataTable->render('dashboard.projects.index');
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //

        return view('dashboard.projects.create_edit');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $this->validateProjects($request);
        Project::create(array_merge($request->only(['name','status']),['created_by'=>auth()->id()]));
        alert()->success(__('Success'),__('Create Successfully'));
        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
        return abort(404);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Project $project)
    {
        //
        return view('dashboard.projects.create_edit',compact('project'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Project $project)
    {
        //
        $this->validateProjects($request);
        $updateData=array_merge($request->only('name','status'),['updated_by'=>auth()->id()]);
        $project->update($updateData);
        alert()->success(__('Success'),__('Update Successfully'));
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Project $project)
    {
        //
        $project->deleted_by=auth()->id();
        $project->save();
        $project->delete();
        return response()->json(['success'=>true,'message'=>__('Delete Successful')]);
    }

    public function validateProjects($request){
        $valid=[

            'status'=>'required|in:'.implode(',',config('app.statusArray')),
        ];
        if($request->project){
//            $valid['email']='required|email|unique:projects,email,'.$request->project->id.',NULL,deleted_at,NULL';
            $valid['name']=['required',Rule::unique('projects','name')->whereNull('deleted_at')->ignore($request->project->id,'id')];
        }else{
            $valid['name']=['required',Rule::unique('projects','name')->whereNull('deleted_at')];
        }
        return $request->validate($valid);
    }
    public function deleteMulti(Request $request){
        $count=Project::whereIn('id',$request->IDS)->update(['deleted_by'=>auth()->id(),'deleted_at'=>now()]);
        return response()->json(['success'=>true,'message'=>__('Delete :count Successful',['count'=>$count])]);
    }
    public function export(Request $request){
        switch ($request->export_type){
            case'csv':
                return Excel::download(new ProjectsExport,'projects_'.time().'.csv',\Maatwebsite\Excel\Excel::CSV);
                break;
            case'excel':
                return Excel::download(new ProjectsExport,'projects_'.time().'.xlsx',\Maatwebsite\Excel\Excel::XLSX);
                break;
            case'pdf':
                $projects=Project::query();
                if(request('IDS')){
                    $projects=$projects->whereIn('id',explode(',',request('IDS')));
                }
                $projects=$projects->get();
                return Pdf::loadView('dashboard.projects.export_pdf',['projects'=>$projects])->download('projects_'.time().'.pdf');
                break;
        }

    }

}
